@@ -1,7 +1,7 @@
 as.SpatialGridDataFrame <- function(bathy) {
 	
-	require(raster)
-	require(sp)
+	# require(raster)
+	# require(sp)
 	
 	out <- as(as.raster(bathy), "SpatialGridDataFrame")
 	return(out)
